/*
    scconfig - guile lib detection
    Copyright (C) 2009  Tibor Palinkas

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

		Project page: http://repo.hu/projects/scconfig
		Contact via email: scconfig [at] igor2.repo.hu
*/

#include "scripts.h"
#include <unistd.h>


int find_script_guile(int logdepth, int fatal)
{
	char *cflags, *ldflags, *tmpc, *tmpl;

	char *test_c =
		NL "#include <libguile.h>"
		NL "int main(int argc, char *argv[]) {"
		NL "	scm_init_guile();"
		NL
		NL "	puts(\"OK\");"
		NL "	return 0;"
		NL "}"
		NL;

	require("cc/cc", logdepth, fatal);

	report("Checking for guile... ");
	logprintf(logdepth, "find_guile: trying to find guile...\n");
	logdepth++;

	if (run(logdepth, "guile-config compile", &tmpc) + run(logdepth, "guile-config link", &tmpl) > 0) {
		free(tmpl);
		free(tmpc);
		put("libs/script/guile/presents", sfalse);
		report("FAILED (guile-config failed)\n");
		return 1;
	}

	cflags = malloc(strlen(tmpc)+4);
	sprintf(cflags, "+%s", strip(tmpc));
	free(tmpc);
	ldflags = malloc(strlen(tmpl)+4);
	sprintf(ldflags, "+%s", strip(tmpl));
	free(tmpl);

	/* TODO: do we need -ldl? */
	if (try_script(logdepth, "libs/script/guile", test_c, cflags, ldflags)) {
		free(ldflags);
		free(cflags);
		return 0;
	}

	free(ldflags);
	free(cflags);

	put("libs/script/guile/presents", sfalse);
	report("Not found\n");
	return 1;
}
